/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 * shintaro.fujiwara@gmail.com
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */
#include <QApplication>
#include <QtNetwork>
#include <QDir>
#include <QDesktopWidget>

#include "downloader.h"

int main(int argc, char *argv[])
{
	QApplication app(argc, argv);
	QUrl url("ftp://ftp.riken.jp/Linux/fedora/");
	QString version;
	if (argc >= 2){
		url = argv[1];
		version = argv[2];
	}
	//call downloader
	Downloader downloader(url, version);
	QObject::connect(&downloader, SIGNAL(finished()),
		&app, SLOT(quit()));
        downloader.show();
	return app.exec();
/*
     Q_INIT_RESOURCE(ftp);
 #ifdef Q_OS_SYMBIAN
     // Change current directory from default private to c:\data
     // in order that user can access the downloaded content
     QDir::setCurrent( "c:\\data" );
 #endif
     QApplication app(argc, argv);
     FtpWindow ftpWin;
 #ifdef Q_OS_SYMBIAN
     // Make application better looking and more usable on small screen
     ftpWin.showMaximized();
 #else
     ftpWin.show();
 #endif
     return ftpWin.exec();
*/
}
